@@ -1,4 +1,4 @@
-from delta_lake import DataLake
+from delta_lake.DataLake import DataLake
 
 class Silver(DataLake):
     colums_silver_array = []
